<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\CashierCart;
use App\Models\CashierCartService;
use App\Models\CashierOrder;
use App\Models\Category;
use App\Models\Notification;
use App\Models\Order;
use App\Models\OrderCashierCart;
use App\Models\Product;
use App\Models\ProductService;
use App\Models\ReceiveTime;
use App\Models\Setting;
use App\Models\Token;
use App\User;
use Carbon\Carbon;
use Edujugon\PushNotification\PushNotification;
use Illuminate\Http\Request;

class AddOrdersController extends Controller
{
    public function index()
    {
        $rows = CashierOrder::orderByDesc('id')->get();
        $status = [
            'in_progress' => 'جارى العمل'
            , 'finish' => 'تم اإنتهاء الطلب'
        ];
        return view('admin.add_orders.index', compact('rows', 'status'));
    }

    public function orders_filter_cashier(Request $request)
    {
        if ($request['start'] && $request['end'] == null) {
            $rows = CashierOrder::whereDate('created_at', '>=', Carbon::parse($request['start']))->orderByDesc('id')->get();
        } elseif ($request['start'] == null && $request['end']) {
            $rows = CashierOrder::whereDate('created_at', '<=', Carbon::parse($request['end']))->orderByDesc('id')->get();
        } elseif ($request['start'] && $request['end']) {
            $rows = CashierOrder::whereBetween('created_at', [Carbon::parse($request['start']), Carbon::parse($request['end'])])->orderByDesc('id')->get();
        } else {
            $rows = CashierOrder::orderByDesc('id')->get();
        }
        $status = [
            'in_progress' => 'جارى العمل'
            , 'finish' => 'تم اإنتهاء الطلب'
        ];
        return view('admin.add_orders.index', compact('rows', 'status'));
    }

    public function create()
    {
        $receive_times = ReceiveTime::all();
        $status = [
            'in_progress' => 'جارى العمل'
            , 'finish' => 'تم اإنتهاء الطلب'
        ];
        return view('admin.add_orders.create', compact('receive_times', 'status'));
    }

    public function store(Request $request)
    {
        $request->validate([
            'client_name' => 'required',
            'client_mobile' => 'required',
            'receive_date' => 'required',
            'receive_time' => 'required',
            'delivery_date' => 'required',
            'delivery_time' => 'required',
            'address' => 'required',

        ]);
        $setting = Setting::first();
        if ($setting) {
            $tax = $setting->tax ? $setting->tax : 0;
            $delivery_cost = $setting->delivery_cost ? $setting->delivery_cost : 0;
            $receive_cost = $setting->receive_cost ? $setting->receive_cost : 0;
        } else {
            $tax = 0;
            $delivery_cost = 0;
            $receive_cost = 0;
        }
        $order = new CashierOrder();
        $order->cashier_id = \Auth::guard('admin')->user()->id;
        $order->client_name = $request->client_name;
        $order->client_mobile = $request->client_mobile;
        $order->receive_date = $request->receive_date;
        $order->receive_time = $request->receive_time;
        $order->delivery_date = $request->delivery_date;
        $order->delivery_time = $request->delivery_time;
        $order->address = $request->address;
        $order->notes = $request->note;
//      $order->rest_amount = $request->rest_amount;
        $order->tax = $tax;
        if ($request->delivery == 'delivery') {
            $order->delivery_status = 'true';
            $order->delivery_cost = $delivery_cost;
            $order->receive_cost = 0;
        }
        $order->status = $request->status;
        $order->save();
        $code = rand('111', '999');
        $order->code = $order->id . $code;
        $order->all_total_price = $order->delivery_cost;
        $order->update();
        return redirect()->route('add_orders.edit', $order->id);

    }

    public function edit($id)
    {
        $products = Product::all();
        $row = CashierOrder::find($id);
        $status = [
            'in_progress' => 'جارى العمل'
            , 'finish' => 'تم اإنتهاء الطلب'
        ];
        $receive_times = ReceiveTime::all();

        $drivers = User::where('status', 'active')->whereType('driver')->get();
        $rows = $row->carts;
        $categories = Category::whereStatus('active')->get();
        return view('admin.add_orders.edit', compact('row', 'drivers', 'status', 'products', 'receive_times', 'rows', 'categories'));

    }

    public function get_category_products(Request $request)
    {
        $products = Product::whereCategoryId($request['category_id'])->get();
        $products_view = view('admin.add_orders.products_view', compact('products'))->render();
        return response()->json(['value' => true, 'products_view' => $products_view]);
    }

    public function get_product_services(Request $request)
    {
        $product = Product::find($request['product_id']);
        $services = $product->services;
        $services_view = view('admin.add_orders.services_view', compact('services'))->render();
        return response()->json(['value' => true, 'services_view' => $services_view]);
    }

    public function update($id, Request $request)
    {
        $request->validate([
            'client_name' => 'required',
            'client_mobile' => 'required',
            'receive_date' => 'required',
            'receive_time' => 'required',
            'delivery_date' => 'required',
            'delivery_time' => 'required',
            'address' => 'required',
            'status' => 'required|in:in_progress,finished'
        ]);
        $order = CashierOrder::find($id);
        $order->client_name = $request->client_name;
        $order->client_mobile = $request->client_mobile;
        $order->receive_date = $request->receive_date;
        $order->receive_time = $request->receive_time;
        $order->delivery_date = $request->delivery_date;
        $order->delivery_time = $request->delivery_time;
        $order->address = $request->address;
        $order->notes = $request->note;
        $order->rest_amount = $request->rest_amount;
        $order->paid_amount = $request->paid_amount;
        if (!$request->delivery) {
            $order->delivery_cost = 0;
            $order->receive_cost = 0;
        }
        $order->status = $request->status;
        $order->update();
        return redirect()->route('add_orders.show', $order->id);
    }

    public function show($id)
    {
        $row = CashierOrder::find($id);
        $status = [
            'in_progress' => 'جارى العمل'
            , 'finish' => 'تم اإنتهاء الطلب'
        ];
        $carts = $row->carts;
        return view('admin.add_orders.show', compact('row', 'status', 'carts'));
    }

    public function destroy($id)
    {
        CashierOrder::destroy($id);
        toast('تم الحذف بنجاح', 'success');
        return redirect()->back();
    }

    public function add_product_order($id, Request $request)
    {
        $request->validate([
            'category_id' => 'required',
            'product_id' => 'required',
            'services' => 'required|array',
            'count' => 'required|numeric'
        ]);

        $order = CashierOrder::find($id);

        $cart = new CashierCart();
        $cart['product_id'] = $request['product_id'];
        $cart['count'] = $request['count'];
        $cart['status'] = 'order';
        $cart->save();


        foreach ($request['services'] as $service) {
            CashierCartService::create([
                'cart_id' => $cart->id,
                'service_id' => $service
            ]);
            $service_price = ProductService::where(['product_id' => $request['product_id'], 'service_id' => $service])->value('price');

            $cart->price += $service_price * $request['count'];
        }
        $cart->update();
        OrderCashierCart::create([
            'order_id' => $order->id,
            'cart_id' => $cart->id,
        ]);


        $required_tax = $cart->price * $order->tax / 100;
        $order->total_price += $cart->price;


        $order->all_total_price += $cart->price + $required_tax;

        $order->update();


        toast('تم اضافه المنتج للطلب', 'success');
        return redirect()->back();


    }


    public function delete_cashier_cart($cart_id, $order_id)
    {
        $cart = CashierCart::find($cart_id);
        $order = CashierOrder::find($order_id);
        $order->total_price -= $cart->price;
        $order->all_total_price -= $cart->price;
        $cart_tax = $cart->price * $order->tax / 100;
        $order->all_total_price -= $cart_tax;
        $order->update();

        CashierCart::destroy($cart_id);

        toast('تم حذف للطلب', 'success');
        return redirect()->back();
    }

    public function update_order_cart($cart_id, $order_id, Request $request)
    {


        $request->validate([
            'product_id' => 'required',
            'category_id' => 'required',
            'count' => 'required',
            'services' => 'required|array'
        ]);

        $cart = CashierCart::find($cart_id);
        $order = CashierOrder::find($order_id);
        $order->total_price -= $cart->price;
        $order->all_total_price -= $cart->price;
        $cart_tax = $cart->price * $order->tax / 100;
        $order->all_total_price -= $cart_tax;
        $order->update();
        $cart->count = \request()->count;
        $cart->product_id = \request()->product_id;
        $cart->update();

        CashierCartService::where([
            'cart_id' => $cart->id,
        ])->delete();

        foreach ($request['services'] as $service) {
            CashierCartService::create([
                'cart_id' => $cart->id,
                'service_id' => $service
            ]);
            $service_price = ProductService::where(['product_id' => $request['product_id'], 'service_id' => $service])->value('price');

            $cart->price += $service_price * $request['count'];
        }
        $cart->update();
        $required_tax = $cart->price * $order->tax / 100;
        $order->total_price += $cart->price;


        $order->all_total_price += $cart->price + $required_tax;

        $order->update();
        toast('تم تعديل للطلب', 'success');
        return redirect()->back();

    }

    public function invoice_add($id)
    {
        $status = [
             'in_progress' => 'جارى العمل', 'finish' => 'تم اإنتهاء الطلب'
        ];
        $setting = Setting::first();
        $order = CashierOrder::find($id);
        $carts = $order->carts()->get();
        return view('admin.add_orders.invoice', compact('setting', 'order', 'carts', 'status'));
    }
}
