<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Notification;
use App\Models\Order;
use App\Models\Setting;
use App\Models\Token;
use App\User;
use Carbon\Carbon;
use Edujugon\PushNotification\PushNotification;
use Illuminate\Http\Request;

class AppOrdersController extends Controller
{
    public function index()
    {
        $rows = Order::orderByDesc('id')->where('status', '!=', 'in_complete')->get();
        $status = [
            'in_complete' => 'غير مكتمل'


            , 'waiting' => 'جديد / حالة الإنتظار'
            , 'accepted' => 'تم موافقة',
            'driver_accept' => 'تم موافقة السائق',
            'driver_in_way' => 'السائق في الطريق', 'driver_take_clothes' => 'السائق أخذ الملابس', 'washing' => 'في حالة الغسيل', 'clothes_back' => 'الملابس في طريق العميل', 'finish' => 'تم اإنتهاء الطلب', 'cancel' => 'تم إلغاء الطلب', 'clothes_finish_wash' => 'تم الانتهاء من غسل الملابس '
        ];
        return view('admin.app_orders.index', compact('rows', 'status'));
    }

    public function orders_filter(Request $request)
    {
        if ($request['start'] && $request['end'] == null) {
            $rows = Order::whereDate('created_at', '>=', Carbon::parse($request['start']))->orderByDesc('id')->get();
        } elseif ($request['start'] == null && $request['end']) {
            $rows = Order::whereDate('created_at', '<=', Carbon::parse($request['end']))->orderByDesc('id')->get();
        } elseif ($request['start'] && $request['end']) {
            $rows = Order::whereBetween('created_at', [Carbon::parse($request['start']), Carbon::parse($request['end'])])->orderByDesc('id')->get();
        } else {
            $rows = Order::orderByDesc('id')->get();
        }
        $status = [
            'in_complete' => 'غير مكتمل'


            , 'waiting' => 'جديد / حالة الإنتظار'
            , 'accepted' => 'تم موافقة',
            'driver_accept' => 'تم موافقة السائق',
            'driver_in_way' => 'السائق في الطريق', 'driver_take_clothes' => 'السائق أخذ الملابس', 'washing' => 'في حالة الغسيل', 'clothes_back' => 'الملابس في طريق العميل', 'finish' => 'تم اإنتهاء الطلب', 'cancel' => 'تم إلغاء الطلب', 'clothes_finish_wash' => 'تم الانتهاء من غسل الملابس '
        ];
        return view('admin.app_orders.index', compact('rows', 'status'));
    }

    public function edit($id)
    {
        $row = Order::find($id);
        $status = [
            'in_complete' => 'غير مكتمل', 'waiting' => 'جديد / حالة الإنتظار', 'accepted' => 'تم موافقة', 'driver_accept' => 'تم موافقة السائق', 'driver_in_way' => 'السائق في الطريق', 'driver_take_clothes' => 'السائق أخذ الملابس', 'washing' => 'في حالة الغسيل', 'clothes_back' => 'الملابس في طريق العميل', 'finish' => 'تم اإنتهاء الطلب', 'cancel' => 'تم إلغاء الطلب', 'clothes_finish_wash' => 'تم الانتهاء من غسل الملابس '
        ];
        $drivers = User::where('status', 'active')->whereType('driver')->get();
        return view('admin.app_orders.edit', compact('row', 'drivers', 'status'));

    }

    public function update($id, Request $request)
    {
        $request->validate([
            'status' => 'required',
            'mandob_id' => 'nullable',
        ]);


        Order::whereId($id)->update([
            'status' => $request['status'],
            'mandob_id' => $request['mandob_id']
        ]);

        if ($request['mandob_id']) {
            $tokens = Token::whereUserId($request['mandob_id'])->where('status', 'connected')->get();


            $notification = new Notification();
            $notification['user_id'] = $request['mandob_id'];
            $notification['body->ar'] = "لديك طلب جديد للتوصيل";
            $notification['body->en'] = "you have a new order to deliver";
            $notification['type'] = 'order';
            $notification['order_id'] = $id;
            $notification->save();


            foreach ($tokens as $token) {
                if ($token->device_language = 'ar') {
                    $title = $notification['body->ar'];
                    $body = $notification['body->ar'];
                } else {
                    $title = $notification['body->en'];
                    $body = $notification['body->en'];
                }
                $push = new PushNotification('fcm');

                if ($token->device_type == 'ios') {

                    $msg = [
                        'data' => [
                            'title_ar' => $notification['body->ar'],
                            'title' => $title,
                            'body' => $body,
                            'title_en' => $notification['body_en'],
                            'body_ar' => $notification['body->ar'],
                            'body_en' => $notification['body_en'],
                            'type' => 'order',
                            'order_id' => $id,
                            'sound' => 'default',
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'notification' => [
                            'title_ar' => $notification['body->ar'],
                            'title_en' => $notification['body->en'],
                            'body_ar' => $notification['body->ar'],
                            'body_en' => $notification['body->en'],
                            'type' => 'order',
                            'title' => $title,
                            'body' => $body,
                            'order_id' => $id,

                            'sound' => 'default',
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'priority' => 'high',
                    ];
                    $push->setMessage($msg)
                        ->setDevicesToken($token->token)
                        ->send();

                } else {
                    $msg = [
                        'data' => [
                            'title_ar' => $notification['body->ar'],
                            'title_en' => $notification['body->en'],
                            'body_ar' => $notification['body->ar'],
                            'body_en' => $notification['body->en'],
                            'type' => 'order',
                            'title' => $title,
                            'body' => $body,
                            'order_id' => $id,

                            'sound' => 'default',
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'priority' => 'high',
                    ];
                    $push->setMessage($msg)
                        ->setDevicesToken($token->token)
                        ->send();

                }

            }
        }
        // notification to driver

        toast('تمت العملية بنجاح', 'success');
        return redirect()->route('app_orders.index');
    }

    public function show($id)
    {
        $row = Order::find($id);
        $status = [
            'in_complete' => 'غير مكتمل', 'waiting' => 'جديد / حالة الإنتظار', 'accepted' => 'تم موافقة', 'driver_accept' => 'تم موافقة السائق', 'driver_in_way' => 'السائق في الطريق', 'driver_take_clothes' => 'السائق أخذ الملابس', 'washing' => 'في حالة الغسيل', 'clothes_back' => 'الملابس في طريق العميل', 'finish' => 'تم اإنتهاء الطلب', 'cancel' => 'تم إلغاء الطلب', 'clothes_finish_wash' => 'تم الانتهاء من غسل الملابس '
        ];
        $carts = $row->carts;
        return view('admin.app_orders.show', compact('row', 'status', 'carts'));
    }

    public function destroy($id)
    {
        Order::destroy($id);
        toast('تم الحذف بنجاح', 'success');
        return redirect()->back();
    }

    public function invoice_app($id)
    {
        $status = [
            'in_complete' => 'غير مكتمل', 'waiting' => 'جديد / حالة الإنتظار', 'accepted' => 'تم موافقة', 'driver_accept' => 'تم موافقة السائق', 'driver_in_way' => 'السائق في الطريق', 'driver_take_clothes' => 'السائق أخذ الملابس', 'washing' => 'في حالة الغسيل', 'clothes_back' => 'الملابس في طريق العميل', 'finish' => 'تم اإنتهاء الطلب', 'cancel' => 'تم إلغاء الطلب', 'clothes_finish_wash' => 'تم الانتهاء من غسل الملابس '
        ];
        $setting = Setting::first();
        $order = Order::find($id);
        $carts = $order->carts()->get();
        return view('admin.app_orders.invoice', compact('setting', 'order', 'carts', 'status'));
    }
}
