<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Bank;
use Illuminate\Http\Request;

class BanksController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $rows = Bank::latest()->get();
        return view('admin.banks.index', compact('rows'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.banks.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'bank_name' => 'required',
            'account_name' => 'required',
            'account_number' => 'required',
            'account_iban' => 'required',
            'image' => 'required|image'
        ]);
        $bank = new Bank();
        $bank['bank_name'] = $request['bank_name'];
        $bank['account_name'] = $request['account_name'];
        $bank->account_number = $request['account_number'];
        $bank->account_iban = $request['account_iban'];
        if ($request->hasFile('image')) {
            $bank->setImageAttribute();
        }
        $bank->save();
        toast('تمت العملية بنجاح', 'success', 'left');
        return redirect()->route('banks.index');
    }

    /**
     * Display the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $row = Bank::find($id);
        return view('admin.banks.edit', compact('row'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'bank_name' => 'required',
            'account_name' => 'required',
            'account_number' => 'required',
            'account_iban' => 'required',
            'image' => 'nullable|image'

        ]);
        $bank = Bank::find($id);
        $bank['bank_name'] = $request['bank_name'];
        $bank['account_name'] = $request['account_name'];
        $bank->account_number = $request['account_number'];
        $bank->account_iban = $request['account_iban'];
        if ($request->hasFile('image')) {
            $bank->setImageAttribute();
        }
        $bank->update();
        toast('تمت العملية بنجاح', 'success', 'left');
        return redirect()->route('banks.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $bank = Bank::find($id);
        $bank->delete();
        toast('تمت العملية بنجاح', 'success', 'left');
        return back();
    }
}

