<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Admin;
use Illuminate\Http\Request;

class CashierController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $rows = Admin::where('type', 'cashier')->orderByDesc('id')->get();
        return view('admin.cashier.index', compact('rows'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.cashier.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'name' => 'required',
            'email' => 'required|email|unique:admins,email',
            'mobile' => 'nullable|unique:admins,mobile',
            'password' => 'required|min:6',
            'status' => 'required|in:active,not_active'
        ]);
        $admin = new Admin();
        $admin['name'] = $request['name'];
        $admin['email'] = $request['email'];
        $admin['mobile'] = $request['mobile'];
        $admin['type'] = 'cashier';
        $admin['status'] = $request['status'];
        $admin['password'] = bcrypt($request['password']);
        $admin->save();
        toast('تمت العملية بنجاح', 'success', 'left');

        return redirect()->route('cashiers.index');

    }

    /**
     * Display the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $row = Admin::find($id);
        return view('admin.cashier.edit', compact('row'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'email' => 'required|email|unique:admins,email,' . $id,
            'mobile' => 'nullable|unique:admins,mobile,' . $id,
            'status' => 'required|in:active,not_active',
            'password' => 'nullable|min:6'
        ]);
        $admin = Admin::find($id);
        $admin['email'] = $request['email'];
        $admin['mobile'] = $request['mobile'];
        $admin['status'] = $request['status'];
        if ($request['password']) $admin['password'] = bcrypt($request['password']);

        $admin->update();
        toast('تمت العملية بنجاح', 'success', 'left');

        return redirect()->route('cashiers.index');

    }


    /**
     * Remove the specified resource from storage.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        Admin::destroy($id);
        toast('تمت العملية بنجاح', 'success', 'left');

        return redirect()->back();
    }


}
