<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Stock;
use App\Models\StockProcess;
use Illuminate\Http\Request;

class StockesProcessController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $rows = StockProcess::latest()->get();
        return view('admin.stockes_process.index', compact('rows'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $stocks = Stock::all();
        return view('admin.stockes_process.create', compact('stocks'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'stock_id' => 'required|exists:stockes,id',
            'amount' => 'required',

        ]);
        $stockes_process = new StockProcess();
        $stockes_process['stock_id'] = $request['stock_id'];
        $stockes_process['amount'] = $request['amount'];
        $stockes_process['cashier_id'] = \Auth::guard('admin')->user()->id;
        $stockes_process->save();
        toast('تمت العملية بنجاح', 'success', 'left');
        return redirect()->route('stockes_process.index');
    }

    /**
     * Display the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $row = StockProcess::find($id);
        $stocks = Stock::all();
        return view('admin.stockes_process.edit', compact('row', 'stocks'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'stock_id' => 'required|exists:stockes,id',
            'amount' => 'required',
        ]);
        $stockes_process = StockProcess::find($id);
        $stockes_process['stock_id'] = $request['stock_id'];
        $stockes_process['amount'] = $request['amount'];
        $stockes_process->update();
        toast('تمت العملية بنجاح', 'success', 'left');
        return redirect()->route('stockes_process.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        StockProcess::destroy($id);
        toast('تمت العملية بنجاح', 'success', 'left');
        return back();
    }
}
