<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Http\Resources\AddressesResource;
use App\Models\Address;
use Illuminate\Http\Request;
use JWTAuth;

class AddressesController extends Controller
{

    public function index()
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        $rows = $user->addresses;
        return AddressesResource::collection($rows)->additional(['value' => true]);

    }


    public function create()
    {
        //
    }


    public function store(Request $request)
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        $validator = \Validator::make($request->all(), [
            'lat' => 'required',
            'lng' => 'required',
            'street' => 'required',
            'area' => 'required'
        ], [
            'lat.required' => 'Please Open GPS',
            'lng.required' => 'Please Open GPS',
        ]);
      if ($validator->passes()){
          $request['user_id'] = $user->id;
          Address::create($request->all());
          $rows = $user->addresses;
          return AddressesResource::collection($rows)->additional(['value' => true]);
      }else{
          return  response()->json(['value'=>false,'msg'=>$validator->errors()->first()]);
      }

    }


    public function show($id)
    {
        //
    }


    public function edit($id)
    {
        //
    }


    public function update(Request $request, $id)
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
         $validator = \Validator::make($request->all(), [
            'lat' => 'required',
            'lng' => 'required',
            'street' => 'required',
            'area' => 'required'
        ], [
            'lat.required' => 'Please Open GPS',
            'lng.required' => 'Please Open GPS',
        ]);
        if ($validator->passes()){
            $request['user_id'] = $user->id;
            Address::whereId($id)->update($request->all());
            $rows = $user->addresses;
            return AddressesResource::collection($rows)->additional(['value' => true]);
        }else{
            return  response()->json(['value'=>false,'msg'=>$validator->errors()->first()]);
        }
    }


    public function destroy($id)
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        Address::destroy($id);
        $rows = $user->addresses;
        return AddressesResource::collection($rows)->additional(['value' => true]);
    }
}
