<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Http\Resources\CartResource;
use App\Models\Cart;
use App\Models\CartService;
use App\Models\Product;
use App\Models\ProductService;
use App\Models\Service;
use Illuminate\Http\Request;
use JWTAuth;

class CartsController extends Controller
{
    public function my_carts_by_product($id, Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }
        $product = Product::find($id);
        if (!$product) {
            return response()->json(['value' => false, 'msg' => 'لا يوجد منتج بهذا ID', 'code' => 422]);
        }

        $carts = Cart::where(['user_id' => $user->id, 'product_id' => $id, 'status' => 'cart'])->get();
        return CartResource::collection($carts)->additional(['value' => true, 'code' => 200]);
    }

    public function add_to_cart(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }

        $validator = \Validator::make($request->all(), [
            'product_id' => 'required',
            'service_ids' => 'required'

        ]);
        if ($validator->passes()) {
            $service_ids = explode(',', $request->service_ids);
            $cart = new Cart();
            $cart->product_id = $request->product_id;
            $cart->user_id = $user->id;
            $cart->status = 'cart';
            $cart->count = '1';
            $cart->price = ProductService::where('product_id', $request->product_id)->whereIn('service_id', $service_ids)->sum('price');
            $cart->save();
            foreach ($service_ids as $service_id) {
                $cart_service = new CartService();
                $cart_service->service_id = $service_id;
                $cart_service->cart_id = $cart->id;
                $cart_service->save();
            }
            $all_carts = $user->carts()->where('status', 'cart')->latest()->get();
            return CartResource::collection($all_carts)->additional(['value' => true, 'code' => 200]);

        }
        return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);
    }

    public function delete_cart(Request $request, $id)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }

        $cart = Cart::where(['id' => $id, 'user_id' => $user->id, 'status' => 'cart'])->first();
        if (!$cart) {
            return response()->json(['value' => false, 'msg' => 'لا يوجد سله بهذا ID', 'code' => 422]);
        }
        $cart->delete();

        return CartResource::collection($user->carts()->where('status', 'cart')->latest()->get())->additional(['value' => true, 'code' => 200]);

    }

    public function update_cart($id, Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }

        $validator = \Validator::make($request->all(), [
            'service_ids' => 'required'
        ]);
        if ($validator->passes()) {
            $service_ids = explode(',', $request->service_ids);

            $cart = Cart::where(['id' => $id, 'user_id' => $user->id, 'status' => 'cart'])->first();
            if (!$cart) {
                return response()->json(['value' => false, 'msg' => 'لا يوجد سله بهذا ID', 'code' => 422]);
            }

            CartService::where('cart_id', $cart->id)->delete();
            $cart->price = ProductService::where('product_id', $cart->product_id)->whereIn('service_id', $service_ids)->sum('price');
            $cart->update();
            foreach ($service_ids as $service_id) {
                $cart_service = new CartService();
                $cart_service->service_id = $service_id;
                $cart_service->cart_id = $cart->id;
                $cart_service->save();
            }
            return CartResource::collection($user->carts()->where('status', 'cart')->latest()->get())->additional(['value' => true, 'code' => 200]);

        }
        return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);

    }
}
