<?php

namespace App;

use App\Models\Address;
use App\Models\Notification;
use App\Models\Order;
use App\Models\Subscription;
use App\Models\Token;
use App\Models\Cart;
use Illuminate\Notifications\Notifiable;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Tymon\JWTAuth\Contracts\JWTSubject;

class User extends Authenticatable implements JWTSubject
{
    use Notifiable;

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $table = 'users';
    public $timestamps = true;
    protected $fillable = array('name', 'mobile', 'email', 'password', 'type', 'status', 'personal_code', 'confirm_code', 'wallet', 'subscription_id', 'image');

    public function notifications()
    {
        return $this->hasMany(Notification::class, 'user_id');
    }

    public function subscription()
    {
        return $this->belongsTo(Subscription::class, 'subscription_id');
    }

    public function addresses()
    {
        return $this->hasMany(Address::class, 'user_id');
    }

    public function tokens()
    {
        return $this->hasMany(Token::class, 'user_id');
    }

    public function subscription_history()
    {
        return $this->belongsToMany(Subscription::class, 'user_subscriptions', 'user_id', 'subscription_id');
    }

    public function client_orders()
    {
        return $this->hasMany(Order::class, 'user_id');
    }

    public function mandob_orders()
    {
        return $this->hasMany(Order::class, 'mandob_id');
    }

    public function carts()
    {
        return $this->hasMany(Cart::class, 'user_id');
    }

    public function setImageAttribute()
    {
        $file = request()->file('image');
        $destinationPath = 'images/users/';
        $filename = time() . '.' . $file->getClientOriginalExtension();
        $file->move($destinationPath, $filename);
        $this->attributes['image'] = $filename;
    }
//
//    public function getImageAttribute()
//    {
//        if ($this->attributes['image']) {
//            return asset('images/users/') . '/' . $this->attributes['image'];
//        }
//        return asset('logo.png');
//    }

    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [
        'password', 'remember_token',
    ];

    public function getJWTIdentifier()
    {
        return $this->getKey();
    }

    public function getJWTCustomClaims()
    {
        return [];
    }
}
